==> cutetube_1.7.1.tar.gz: cutetube-1.7.1/cutetubeapp/src/maemo5_gui/dailymotionrelatedvideostab.h <==
#ifndef DAILYMOTIONRELATEDVIDEOSTAB_H
#define DAILYMOTIONRELATEDVIDEOSTAB_H

#include "abstracttab.h"
#include "../base/videoitem.h"

class Session;
class DailymotionVideoListModel;
class ListView;
class QAction;
class QLabel;
class QGridLayout;
class QModelIndex;
class QMenu;

class DailymotionRelatedVideosTab : public AbstractTab
{
    Q_OBJECT

public:
    explicit DailymotionRelatedVideosTab(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);

private:
    void setLandscapeLayout();
    void setPortraitLayout();
    void showVideoInfo(QSharedPointer<VideoItem> video);

private slots:
    void setMenuActions();
    void onLoadingChanged(bool loading);
    void onCountChanged(int count);
    void addVideosToFavourites();
    void addVideosToPlaylist();
    void addVideoDownloads();
    void addAudioDownloads();
    void queueVideos();
    void showContextMenu(const QPoint &pos);
    void addVideoToFavourites();
    void showPlaylistDialog();
    void addVideoToPlaylist(const QString &id);
    void addVideoToNewPlaylist(const QVariantMap &playlist);
    void addVideoDownload();
    void addAudioDownload();
    void queueVideo();
    void onItemClicked(const QModelIndex &index);
    void playVideo(const QModelIndex &index);

private:
    Session *m_session;
    QSharedPointer<VideoItem> m_video;
    DailymotionVideoListModel *m_model;
    ListView *m_listView;
    QAction *m_addToFavouritesAction;
    QAction *m_addToPlaylistAction;
    QAction *m_addToQueueAction;
    QAction *m_videoDownloadAction;
    QAction *m_audioDownloadAction;
    QMenu *m_contextMenu;
    QAction *m_addToFavouritesContextAction;
    QAction *m_addToPlaylistContextAction;
    QAction *m_addToQueueContextAction;
    QAction *m_videoDownloadContextAction;
    QAction *m_audioDownloadContextAction;
    QLabel *m_noResultsLabel;
    QGridLayout *m_grid;
};

#endif // DAILYMOTIONRELATEDVIDEOSTAB_H

==> cutetube_1.9.1.tar.gz: cutetube-1.9.1/cutetubeapp/src/maemo5_gui/dailymotionrelatedvideostab.h <==
#ifndef DAILYMOTIONRELATEDVIDEOSTAB_H
#define DAILYMOTIONRELATEDVIDEOSTAB_H

#include "abstracttab.h"
#include "../base/videoitem.h"

class DailymotionVideoListModel;
class ListView;
class QAction;
class QLabel;
class QGridLayout;
class QModelIndex;
class QMenu;

class DailymotionRelatedVideosTab : public AbstractTab
{
    Q_OBJECT

public:
    explicit DailymotionRelatedVideosTab(QSharedPointer<VideoItem> video, QWidget *parent = 0);

private:
    void setLandscapeLayout();
    void setPortraitLayout();
    void showVideoInfo(QSharedPointer<VideoItem> video);

private slots:
    void setMenuActions();
    void onLoadingChanged(bool loading);
    void onCountChanged(int count);
    void addVideosToFavourites();
    void addVideosToPlaylist();
    void addVideoDownloads();
    void addAudioDownloads();
    void queueVideos();
    void showContextMenu(const QPoint &pos);
    void addVideoToFavourites();
    void showPlaylistDialog();
    void addVideoToPlaylist(const QString &id);
    void addVideoToNewPlaylist(const QVariantMap &playlist);
    void addVideoDownload();
    void addAudioDownload();
    void queueVideo();
    void onItemClicked(const QModelIndex &index);
    void playVideo(const QModelIndex &index);

private:
    QSharedPointer<VideoItem> m_video;
    DailymotionVideoListModel *m_model;
    ListView *m_listView;
    QAction *m_addToFavouritesAction;
    QAction *m_addToPlaylistAction;
    QAction *m_addToQueueAction;
    QAction *m_videoDownloadAction;
    QAction *m_audioDownloadAction;
    QMenu *m_contextMenu;
    QAction *m_addToFavouritesContextAction;
    QAction *m_addToPlaylistContextAction;
    QAction *m_addToQueueContextAction;
    QAction *m_videoDownloadContextAction;
    QAction *m_audioDownloadContextAction;
    QLabel *m_noResultsLabel;
    QGridLayout *m_grid;
};

#endif // DAILYMOTIONRELATEDVIDEOSTAB_H
